pygeodesy.azimuthal.Azimuthal7Tuple

Package pygeodesy :: Module azimuthal :: Class Azimuthal7Tuple |
[frames] | no frames]

# Class Azimuthal7Tuple

       object --+
                |
            tuple --+
                    |
       object --+   |
                |   |
     named._Named --+
                    |
    named._NamedTuple --+
                        |
                       Azimuthal7Tuple

7-Tuple `(x, y, lat, lon, azimuth, scale, datum)`, in `meter`, `meter`, `degrees90`, `degrees180`, compass `degrees`, `scalar` and `Datum` where `(x, y)` is the easting and northing of a projected point, `(lat, lon)` the geodetic location, `azimuth` the azimuth, clockwise from true North and `scale` is the projection scale, either `1 / reciprocal` or `1` or `-1` in the Equidistant case.

Instance Methods
antipodal(self, azimuth=None) Return this tuple with the antipodal `lat` and `lon`. |
Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `toUnits`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `named._NamedTuple`: `__new__`

Properties
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### antipodal (self, azimuth=None) |
Return this tuple with the antipodal `lat` and `lon`. Arguments: `azimuth` - Optional azimuth, overriding the current azimuth (`compass degrees360`).